/*
 * Copyright 2022-present MongoDB, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef PHONGO_WRITEERROR_H
#define PHONGO_WRITEERROR_H

#include "bson/bson.h"

#include <php.h>

bool phongo_writeerror_init(zval* return_value, const bson_t* bson);
bool phongo_writeerror_init_ex(zval* return_value, const bson_t* bson, int32_t index);

#endif /* PHONGO_WRITEERROR_H */
